==> open-cluster-management-placementruleapps-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorsplacementrule/apps/v1/PlacementRuleStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PlacementRuleStatusFluent<A extends PlacementRuleStatusFluent<A>> extends BaseFluent<A>{
  public PlacementRuleStatusFluent() {
  }
  public PlacementRuleStatusFluent(PlacementRuleStatus instance) {
    instance = (instance != null ? instance : new PlacementRuleStatus());

    if (instance != null) {
      this.withDecisions(instance.getDecisions());
      this.withDecisions(instance.getDecisions());
    }
  }
  private ArrayList<PlacementDecisionBuilder> decisions = new ArrayList<PlacementDecisionBuilder>();
  public A addToDecisions(int index,PlacementDecision item) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);
    if (index < 0 || index >= decisions.size()) { _visitables.get("decisions").add(builder); decisions.add(builder); } else { _visitables.get("decisions").add(index, builder); decisions.add(index, builder);}
    return (A)this;
  }
  public A setToDecisions(int index,PlacementDecision item) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);
    if (index < 0 || index >= decisions.size()) { _visitables.get("decisions").add(builder); decisions.add(builder); } else { _visitables.get("decisions").set(index, builder); decisions.set(index, builder);}
    return (A)this;
  }
  public A addToDecisions(io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1.PlacementDecision... items) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").add(builder);this.decisions.add(builder);} return (A)this;
  }
  public A addAllToDecisions(Collection<PlacementDecision> items) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").add(builder);this.decisions.add(builder);} return (A)this;
  }
  public A removeFromDecisions(io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1.PlacementDecision... items) {
    if (this.decisions == null) return (A)this;
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").remove(builder); this.decisions.remove(builder);} return (A)this;
  }
  public A removeAllFromDecisions(Collection<PlacementDecision> items) {
    if (this.decisions == null) return (A)this;
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").remove(builder); this.decisions.remove(builder);} return (A)this;
  }
  public A removeMatchingFromDecisions(Predicate<PlacementDecisionBuilder> predicate) {
    if (decisions == null) return (A) this;
    final Iterator<PlacementDecisionBuilder> each = decisions.iterator();
    final List visitables = _visitables.get("decisions");
    while (each.hasNext()) {
      PlacementDecisionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<PlacementDecision> buildDecisions() {
    return decisions != null ? build(decisions) : null;
  }
  public PlacementDecision buildDecision(int index) {
    return this.decisions.get(index).build();
  }
  public PlacementDecision buildFirstDecision() {
    return this.decisions.get(0).build();
  }
  public PlacementDecision buildLastDecision() {
    return this.decisions.get(decisions.size() - 1).build();
  }
  public PlacementDecision buildMatchingDecision(Predicate<PlacementDecisionBuilder> predicate) {
    for (PlacementDecisionBuilder item: decisions) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingDecision(Predicate<PlacementDecisionBuilder> predicate) {
    for (PlacementDecisionBuilder item: decisions) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDecisions(List<PlacementDecision> decisions) {
    if (this.decisions != null) { _visitables.get("decisions").clear();}
    if (decisions != null) {this.decisions = new ArrayList(); for (PlacementDecision item : decisions){this.addToDecisions(item);}} else { this.decisions = null;} return (A) this;
  }
  public A withDecisions(io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1.PlacementDecision... decisions) {
    if (this.decisions != null) {this.decisions.clear(); _visitables.remove("decisions"); }
    if (decisions != null) {for (PlacementDecision item :decisions){ this.addToDecisions(item);}} return (A) this;
  }
  public boolean hasDecisions() {
    return decisions != null && !decisions.isEmpty();
  }
  public A addNewDecision(String clusterName,String clusterNamespace) {
    return (A)addToDecisions(new PlacementDecision(clusterName, clusterNamespace));
  }
  public DecisionsNested<A> addNewDecision() {
    return new DecisionsNested(-1, null);
  }
  public DecisionsNested<A> addNewDecisionLike(PlacementDecision item) {
    return new DecisionsNested(-1, item);
  }
  public DecisionsNested<A> setNewDecisionLike(int index,PlacementDecision item) {
    return new DecisionsNested(index, item);
  }
  public DecisionsNested<A> editDecision(int index) {
    if (decisions.size() <= index) throw new RuntimeException("Can't edit decisions. Index exceeds size.");
    return setNewDecisionLike(index, buildDecision(index));
  }
  public DecisionsNested<A> editFirstDecision() {
    if (decisions.size() == 0) throw new RuntimeException("Can't edit first decisions. The list is empty.");
    return setNewDecisionLike(0, buildDecision(0));
  }
  public DecisionsNested<A> editLastDecision() {
    int index = decisions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last decisions. The list is empty.");
    return setNewDecisionLike(index, buildDecision(index));
  }
  public DecisionsNested<A> editMatchingDecision(Predicate<PlacementDecisionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<decisions.size();i++) { 
    if (predicate.test(decisions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching decisions. No match found.");
    return setNewDecisionLike(index, buildDecision(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementRuleStatusFluent that = (PlacementRuleStatusFluent) o;
    if (!java.util.Objects.equals(decisions, that.decisions)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(decisions,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (decisions != null && !decisions.isEmpty()) { sb.append("decisions:"); sb.append(decisions); }
    sb.append("}");
    return sb.toString();
  }
  public class DecisionsNested<N> extends PlacementDecisionFluent<DecisionsNested<N>> implements Nested<N>{
    DecisionsNested(int index,PlacementDecision item) {
      this.index = index;
      this.builder = new PlacementDecisionBuilder(this, item);
    }
    PlacementDecisionBuilder builder;
    int index;
    public N and() {
      return (N) PlacementRuleStatusFluent.this.setToDecisions(index,builder.build());
    }
    public N endDecision() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-placementruleapps-model-6.9.2-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorsplacementrule/apps/v1/PlacementRuleStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PlacementRuleStatusFluent<A extends PlacementRuleStatusFluent<A>> extends BaseFluent<A>{
  public PlacementRuleStatusFluent() {
  }
  
  public PlacementRuleStatusFluent(PlacementRuleStatus instance) {
    this.copyInstance(instance);
  }
  private ArrayList<PlacementDecisionBuilder> decisions = new ArrayList<PlacementDecisionBuilder>();
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PlacementRuleStatus instance) {
    instance = (instance != null ? instance : new PlacementRuleStatus());
    if (instance != null) {
          this.withDecisions(instance.getDecisions());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToDecisions(int index,PlacementDecision item) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);
    if (index < 0 || index >= decisions.size()) { _visitables.get("decisions").add(builder); decisions.add(builder); } else { _visitables.get("decisions").add(index, builder); decisions.add(index, builder);}
    return (A)this;
  }
  
  public A setToDecisions(int index,PlacementDecision item) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);
    if (index < 0 || index >= decisions.size()) { _visitables.get("decisions").add(builder); decisions.add(builder); } else { _visitables.get("decisions").set(index, builder); decisions.set(index, builder);}
    return (A)this;
  }
  
  public A addToDecisions(io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1.PlacementDecision... items) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").add(builder);this.decisions.add(builder);} return (A)this;
  }
  
  public A addAllToDecisions(Collection<PlacementDecision> items) {
    if (this.decisions == null) {this.decisions = new ArrayList<PlacementDecisionBuilder>();}
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").add(builder);this.decisions.add(builder);} return (A)this;
  }
  
  public A removeFromDecisions(io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1.PlacementDecision... items) {
    if (this.decisions == null) return (A)this;
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").remove(builder); this.decisions.remove(builder);} return (A)this;
  }
  
  public A removeAllFromDecisions(Collection<PlacementDecision> items) {
    if (this.decisions == null) return (A)this;
    for (PlacementDecision item : items) {PlacementDecisionBuilder builder = new PlacementDecisionBuilder(item);_visitables.get("decisions").remove(builder); this.decisions.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromDecisions(Predicate<PlacementDecisionBuilder> predicate) {
    if (decisions == null) return (A) this;
    final Iterator<PlacementDecisionBuilder> each = decisions.iterator();
    final List visitables = _visitables.get("decisions");
    while (each.hasNext()) {
      PlacementDecisionBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<PlacementDecision> buildDecisions() {
    return this.decisions != null ? build(decisions) : null;
  }
  
  public PlacementDecision buildDecision(int index) {
    return this.decisions.get(index).build();
  }
  
  public PlacementDecision buildFirstDecision() {
    return this.decisions.get(0).build();
  }
  
  public PlacementDecision buildLastDecision() {
    return this.decisions.get(decisions.size() - 1).build();
  }
  
  public PlacementDecision buildMatchingDecision(Predicate<PlacementDecisionBuilder> predicate) {
      for (PlacementDecisionBuilder item : decisions) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingDecision(Predicate<PlacementDecisionBuilder> predicate) {
      for (PlacementDecisionBuilder item : decisions) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withDecisions(List<PlacementDecision> decisions) {
    if (this.decisions != null) {
      this._visitables.get("decisions").clear();
    }
    if (decisions != null) {
        this.decisions = new ArrayList();
        for (PlacementDecision item : decisions) {
          this.addToDecisions(item);
        }
    } else {
      this.decisions = null;
    }
    return (A) this;
  }
  
  public A withDecisions(io.fabric8.openclustermanagement.api.model.multicloudoperatorsplacementrule.apps.v1.PlacementDecision... decisions) {
    if (this.decisions != null) {
        this.decisions.clear();
        _visitables.remove("decisions");
    }
    if (decisions != null) {
      for (PlacementDecision item : decisions) {
        this.addToDecisions(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasDecisions() {
    return this.decisions != null && !this.decisions.isEmpty();
  }
  
  public A addNewDecision(String clusterName,String clusterNamespace) {
    return (A)addToDecisions(new PlacementDecision(clusterName, clusterNamespace));
  }
  
  public DecisionsNested<A> addNewDecision() {
    return new DecisionsNested(-1, null);
  }
  
  public DecisionsNested<A> addNewDecisionLike(PlacementDecision item) {
    return new DecisionsNested(-1, item);
  }
  
  public DecisionsNested<A> setNewDecisionLike(int index,PlacementDecision item) {
    return new DecisionsNested(index, item);
  }
  
  public DecisionsNested<A> editDecision(int index) {
    if (decisions.size() <= index) throw new RuntimeException("Can't edit decisions. Index exceeds size.");
    return setNewDecisionLike(index, buildDecision(index));
  }
  
  public DecisionsNested<A> editFirstDecision() {
    if (decisions.size() == 0) throw new RuntimeException("Can't edit first decisions. The list is empty.");
    return setNewDecisionLike(0, buildDecision(0));
  }
  
  public DecisionsNested<A> editLastDecision() {
    int index = decisions.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last decisions. The list is empty.");
    return setNewDecisionLike(index, buildDecision(index));
  }
  
  public DecisionsNested<A> editMatchingDecision(Predicate<PlacementDecisionBuilder> predicate) {
    int index = -1;
    for (int i=0;i<decisions.size();i++) { 
    if (predicate.test(decisions.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching decisions. No match found.");
    return setNewDecisionLike(index, buildDecision(index));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PlacementRuleStatusFluent that = (PlacementRuleStatusFluent) o;
    if (!java.util.Objects.equals(decisions, that.decisions)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(decisions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (decisions != null && !decisions.isEmpty()) { sb.append("decisions:"); sb.append(decisions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class DecisionsNested<N> extends PlacementDecisionFluent<DecisionsNested<N>> implements Nested<N>{
    DecisionsNested(int index,PlacementDecision item) {
      this.index = index;
      this.builder = new PlacementDecisionBuilder(this, item);
    }
    PlacementDecisionBuilder builder;
    int index;
    
    public N and() {
      return (N) PlacementRuleStatusFluent.this.setToDecisions(index,builder.build());
    }
    
    public N endDecision() {
      return and();
    }
    
  
  }

}
